@@ -13,15 +13,13 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import configparser
 import logging
 import logging.handlers
 import os
 import signal
 import sys
 
-import six
-from six import moves
-
 from oslo_rootwrap import filters
 from oslo_rootwrap import subprocess
 
@@ -40,7 +38,7 @@ class FilterMatchNotExecutable(Exception):
         self.match = match
 
 
-class RootwrapConfig(object):
+class RootwrapConfig:
 
     def __init__(self, config):
         # filters_path
@@ -73,13 +71,7 @@ class RootwrapConfig(object):
         if config.has_option("DEFAULT", "syslog_log_level"):
             v = config.get("DEFAULT", "syslog_log_level")
             level = v.upper()
-            if (hasattr(logging, '_nameToLevel') and
-               level in logging._nameToLevel):
-                # Workaround a regression of Python 3.4.0 bug fixed in 3.4.2:
-                # http://bugs.python.org/issue22386
-                self.syslog_log_level = logging._nameToLevel[level]
-            else:
-                self.syslog_log_level = logging.getLevelName(level)
+            self.syslog_log_level = logging.getLevelName(level)
             if (self.syslog_log_level == "Level %s" % level):
                 raise ValueError('Unexpected syslog_log_level: %r' % v)
         else:
@@ -108,7 +100,7 @@ def setup_syslog(execname, facility, level):
     try:
         handler = logging.handlers.SysLogHandler(address='/dev/log',
                                                  facility=facility)
-    except IOError:
+    except OSError:
         logging.warning("Unable to setup syslog, maybe /dev/log socket needs "
                         "to be restarted. Ignoring syslog configuration "
                         "options.")
@@ -142,8 +134,8 @@ def load_filters(filters_path):
             filterfilepath = os.path.join(filterdir, filterfile)
             if not os.path.isfile(filterfilepath):
                 continue
-            kwargs = {"strict": False} if six.PY3 else {}
-            filterconfig = moves.configparser.RawConfigParser(**kwargs)
+            kwargs = {"strict": False}
+            filterconfig = configparser.RawConfigParser(**kwargs)
             filterconfig.read(filterfilepath)
             for (name, value) in filterconfig.items("Filters"):
                 filterdefinition = [s.strip() for s in value.split(',')]
@@ -220,7 +212,7 @@ def start_subprocess(filter_list, userargs, exec_dirs=[], log=False, **kwargs):
 
     command = filtermatch.get_command(userargs, exec_dirs)
     if log:
-        logging.info("(%s > %s) Executing %s (filter match = %s)" % (
+        logging.info("({} > {}) Executing {} (filter match = {})".format(
             _getlogin(), pwd.getpwuid(os.getuid())[0],
             command, filtermatch.name))
 
